@@ -107,7 +107,7 @@ except ImportError:
                           " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.3.4'
+__version__ = '2.3.5'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
@@ -256,7 +256,7 @@ class CronTab(object):
         """Catch setting crons and lines directly"""
         if name == 'lines' and value:
             for line in value:
-                self.append(CronItem(line, cron=self), line, read=True)
+                self.append(CronItem.from_line(line, cron=self), line, read=True)
         elif name == 'crons' and value:
             raise AttributeError("You can NOT set crons attribute directly")
         else:
@@ -412,14 +412,14 @@ class CronTab(object):
         """
         if not user and self.user is False:
             raise ValueError("User is required for system crontabs.")
-        item = CronItem(None, command, comment, user, self)
+        item = CronItem(command, comment, user=user, cron=self)
         self.append(item)
         return item
 
     def find_command(self, command):
         """Return an iter of jobs matching any part of the command."""
         for job in list(self.crons):
-            if isinstance(command, re._pattern_type):
+            if isinstance(command, type(ITEMREX)):
                 if command.findall(job.command):
                     yield job
             elif command in job.command:
@@ -428,7 +428,7 @@ class CronTab(object):
     def find_comment(self, comment):
         """Return an iter of jobs that match the comment field exactly."""
         for job in list(self.crons):
-            if isinstance(comment, re._pattern_type):
+            if isinstance(comment, type(ITEMREX)):
                 if comment.findall(job.comment):
                     yield job
             elif comment == job.comment:
@@ -510,7 +510,7 @@ class CronTab(object):
         return 1
 
     def __repr__(self):
-        kind = 'System ' if self._user == False else ''
+        kind = 'System ' if self._user is False else ''
         if self.filen:
             return "<%sCronTab '%s'>" % (kind, self.filen)
         elif self.user and not self.user_opt:
@@ -542,7 +542,7 @@ class CronItem(object):
     An item which objectifies a single line of a crontab and
     May be considered to be a cron job object.
     """
-    def __init__(self, line=None, command='', comment='', user=None, cron=None):
+    def __init__(self, command='', comment='', user=None, cron=None):
         self.cron = cron
         self.user = user
         self.valid = False
@@ -563,12 +563,17 @@ class CronItem(object):
 
         self.set_comment(comment)
 
-        if line and line.strip():
-            self.parse(line.strip())
-        elif command:
+        if command:
             self.set_command(command)
             self.valid = True
 
+    @classmethod
+    def from_line(cls, line, user=None, cron=None):
+        """Generate CronItem from a cron-line and parse out command and comment"""
+        obj = cls(user=user, cron=cron)
+        obj.parse(line.strip())
+        return obj
+
     def delete(self):
         """Delete this item and remove it from it's parent"""
         if not self.cron:
@@ -742,22 +747,7 @@ class CronItem(object):
         except ImportError:
             raise ImportError("Croniter not available. Please install croniter"
                               " python module via pip or your package manager")
-
-        class Croniter(croniter):
-            """Same as normal croniter, but always return datetime objects"""
-            def get_next(self, type_ref=datetime):
-                """Get the next date as a datetime"""
-                return croniter.get_next(self, type_ref)
-
-            def get_prev(self, type_ref=datetime):
-                """Get the previous date as a datetime"""
-                return croniter.get_prev(self, type_ref)
-
-            def get_current(self, type_ref=datetime):
-                """Get the current date as a datetime"""
-                return croniter.get_current(self, type_ref)
-
-        return Croniter(self.slices.clean_render(), date_from)
+        return croniter(self.slices.clean_render(), date_from, ret_type=datetime)
 
     def description(self, **kw):
         """
@@ -1045,14 +1035,13 @@ class CronSlice(object):
 
     def parse(self, value):
         """Set values into the slice."""
-        self.parts = []
-        if value is None:
-            return self.clear()
-        for part in unicode(value).split(','):
-            if part.find("/") > 0 or part.find("-") > 0 or part == '*':
-                self.parts += self.get_range(part)
-                continue
-            self.parts.append(self.parse_value(part, sunday=0))
+        self.clear()
+        if value is not None:
+            for part in unicode(value).split(','):
+                if part.find("/") > 0 or part.find("-") > 0 or part == '*':
+                    self.parts += self.get_range(part)
+                    continue
+                self.parts.append(self.parse_value(part, sunday=0))
 
     def render(self, resolve=False):
         """Return the slice rendered as a crontab.
@@ -1060,7 +1049,7 @@ class CronSlice(object):
         resolve - return integer values instead of enums (default False)
 
         """
-        if len(self.parts) == 0:
+        if not self.parts:
             return '*'
         return _render_values(self.parts, ',', resolve)
 
@@ -1167,10 +1156,10 @@ def get_cronvalue(value, enums):
     return CronValue(unicode(value), enums)
 
 
-class CronValue(object):
+class CronValue(object): # pylint: disable=too-few-public-methods
     """Represent a special value in the cron line"""
     def __init__(self, value, enums):
-        self.enum = value
+        self.text = value
         self.value = enums.index(value.lower())
 
     def __lt__(self, value):
@@ -1180,7 +1169,7 @@ class CronValue(object):
         return unicode(self)
 
     def __str__(self):
-        return self.enum
+        return self.text
 
     def __int__(self):
         return self.value
@@ -1215,7 +1204,7 @@ class CronRange(object):
             self.all()
         elif isinstance(vrange[0], basestring):
             self.parse(vrange[0])
-        elif isinstance(vrange[0], int) or isinstance(vrange[0], CronValue):
+        elif isinstance(vrange[0], (int, CronValue)):
             if len(vrange) == 2:
                 (self.vfrom, self.vto) = vrange
             else:
@@ -1340,7 +1329,6 @@ class OrderedVariableList(OrderedDict):
     def __str__(self):
         """Constructs to variable list output used in cron jobs"""
         ret = []
-        previous = self.previous.all() if self.previous else None
         for key, value in self.items():
             if self.previous:
                 if self.previous.all().get(key, None) == value:
@@ -1350,5 +1338,3 @@ class OrderedVariableList(OrderedDict):
             ret.append("%s=%s" % (key, unicode(value)))
         ret.append('')
         return "\n".join(ret)
-
-
